@@ -323,7 +323,7 @@ public class ContentAssistant implements IContentAssistant, IContentAssistantExt
 
 			// Only act on characters that are trigger candidates. This
 			// avoids computing the model selection on every keystroke
-			if (computeAllAutoActivationTriggers().indexOf(e.character) < 0) {
+			if (!isAutoActivationTriggerChar(e.character)) {
 				stop();
 				return;
 			}
@@ -935,7 +935,8 @@ public class ContentAssistant implements IContentAssistant, IContentAssistantExt
 
 	private Closer fCloser;
 	LayoutManager fLayoutManager;
-	private AutoAssistListener fAutoAssistListener;
+
+	AutoAssistListener fAutoAssistListener;
 	private InternalListener fInternalListener;
 	private CompletionProposalPopup fProposalPopup;
 	private ContextInformationPopup fContextInfoPopup;
@@ -1055,6 +1056,8 @@ public class ContentAssistant implements IContentAssistant, IContentAssistantExt
 	 */
 	private boolean fAsynchronous;
 
+	private boolean fCompletionProposalTriggerCharsEnabled= true;
+
 	/**
 	 * Creates a new content assistant. The content assistant is not automatically activated,
 	 * overlays the completion proposals with context information list if necessary, and shows the
@@ -1181,27 +1184,26 @@ public class ContentAssistant implements IContentAssistant, IContentAssistantExt
 	}
 
 	/**
-	 * Computes the sorted set of all auto activation trigger characters.
-	 *
-	 * @return the sorted set of all auto activation trigger characters
-	 * @since 3.1
+	 * @return whether the given char is an auto-activation trigger char
+	 * @since 3.15
 	 */
-	private String computeAllAutoActivationTriggers() {
+	boolean isAutoActivationTriggerChar(char c) {
 		if (fProcessors == null)
-			return ""; //$NON-NLS-1$
+			return false;
 
-		StringBuilder buf= new StringBuilder(5);
 		for (Set<IContentAssistProcessor> processorsForContentType : fProcessors.values()) {
 			for (IContentAssistProcessor processor : processorsForContentType) {
 				char[] triggers= processor.getCompletionProposalAutoActivationCharacters();
-				if (triggers != null)
-					buf.append(triggers);
+				if (triggers != null && new String(triggers).indexOf(c) >= 0) {
+					return true;
+				}
 				triggers= processor.getContextInformationAutoActivationCharacters();
-				if (triggers != null)
-					buf.append(triggers);
+				if (triggers != null && new String(triggers).indexOf(c) >= 0) {
+					return true;
+				}
 			}
 		}
-		return buf.toString();
+		return false;
 	}
 
 	/**
@@ -2757,4 +2759,32 @@ public class ContentAssistant implements IContentAssistant, IContentAssistantExt
 			fProposalPopup.setSorter(fSorter);
 		}
 	}
+
+	/**
+	 * Returns whether completion trigger char are enabled. If false, completion proposal trigger
+	 * chars are ignored and only Enter key can be used to select a proposal.
+	 *
+	 * @return whether completion trigger char are enabled.
+	 * @see ICompletionProposalExtension#getTriggerCharacters()
+	 * @since 3.15
+	 */
+	public boolean isCompletionProposalTriggerCharsEnabled() {
+		return fCompletionProposalTriggerCharsEnabled;
+	}
+
+	/**
+	 * Set whether completion trigger chars are enabled. If set to false, completion proposal
+	 * trigger chars are ignored and only Enter key can be used to select a proposal.
+	 *
+	 * @param enable whether current content assistant should consider completion trigger chars.
+	 * @see ICompletionProposalExtension#getTriggerCharacters()
+	 * @since 3.15
+	 */
+	public void enableCompletionProposalTriggerChars(boolean enable) {
+		fCompletionProposalTriggerCharsEnabled= enable;
+	}
+
+	boolean isAutoActivation() {
+		return fIsAutoActivated;
+	}
 }
